$(function () {
    $('.set_example').click(function () {
        var el = $(this);
        el.parent().removeClass('ignore_me').find('textarea').html(el.data('text'));
        el.hide();
        return false;
    });
    $('.trans_text').change(function(){
        $(this).parent().removeClass('ignore_me');
    });
    $('#trans_form').submit(function(){
        $('.ignore_me input').remove();
        $('.ignore_me textarea').attr('disabled', 'disabled');
    });
    $('#import_file').change(function(){
        $('#import_form').submit();
    });
});