<?php

// Buttons
$lang['save_btn'] = 'Зберегти';
$lang['cancel_btn'] = 'Відміна';
$lang['delete_btn'] = 'Видалити';
$lang['change_btn'] = 'Редагувати';

// Pages
$lang['page_admin'] = 'Адмін панель';

// Message
$lang['msg_head_error'] = 'помилка';
$lang['msg_access_denied'] = 'У Вас недостатньо прав! Ви можете:';
$lang['msg_back'] = 'Повернутись на попередню сторінку';
$lang['msg_relogin'] = 'Авторизуватись знову';
$lang['no data found'] = 'Не має подій для відображення';
$lang['Warning! Project is in development mode'] = '<b>Увага!</b> Проект в режимі "development"';

// Top menu items
$lang['top_menu_1'] = 'Оновлення';
$lang['top_menu_2'] = 'Панель керування';
$lang['top_menu_3'] = 'Файл-менеджер';
$lang['top_menu_4'] = 'SEO-модуль';
$lang['top_menu_5'] = 'Панель розробника';

// Menu
$lang['menu_back_text'] = '<span>«</span>Назад';
$lang['menu_next_text'] = 'Вперед';
$lang['menu_title'] = 'Меню';
$lang['home_btn'] = 'Домашня';
$lang['site_btn'] = 'На сайт';
$lang['exit_btn'] = 'Вийти';

// menu blocks
$lang['block_up_text'] = 'звернути';
$lang['block_down_text'] = 'розвернути';

// search menu
$lang['search_text'] = 'пошук ...';
$lang['search_title'] = 'Результати пошуку:';

$lang['active'] = 'Так';
$lang['no_active'] = 'Ні';

$lang['Translate manager'] = 'Менеджер перекладів';
$lang['Translations was saved'] = 'Переклади збережені';
$lang['For example'] = 'Наприклад';
$lang['Set default text'] = 'Встановити текст за замовчуванням';
$lang['File imported. Records count %s. Please, check and save changes.'] = 'Файл імпортований. Кількість записів %s. Будь ласка, перевірте та збережіть зміни.';
$lang['Please, upload a file.'] = 'Будь ласка, завантажте файл.';
$lang['Keys'] = 'Ключі';
$lang['Translation key'] = 'Ключ перекладу';
$lang['Example'] = 'Приклад';