<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

/**
 * Upgrade ciext module to version 3.3.3
 *
 * @author Igor Ratsun
 */
class Ciext_upgrade_3_3_1 extends \Ciext\Migration\AbstractUpgrade
{

    public function up()
    {
        get_instance()->db->query('ALTER TABLE `acl_user` MODIFY `email` VARCHAR(255);');

        return '3.3.3';
    }

    public function down()
    {
        get_instance()->db->query('ALTER TABLE `acl_user` MODIFY `email` VARCHAR(32);');
        
        return '3.3.1';
    }
}
